@@ -1,36 +1,13 @@
 /*
- * DEBUG: section 86    ESI processing
- * AUTHOR: Robert Collins
+ * Copyright (C) 1996-2018 The Squid Software Foundation and contributors
  *
- * SQUID Web Proxy Cache          http://www.squid-cache.org/
- * ----------------------------------------------------------
- *
- *  Squid is the result of efforts by numerous individuals from
- *  the Internet community; see the CONTRIBUTORS file for full
- *  details.   Many organizations have provided support for Squid's
- *  development; see the SPONSORS file for full details.  Squid is
- *  Copyrighted (C) 2001 by the Regents of the University of
- *  California; see the COPYRIGHT file for full details.  Squid
- *  incorporates software developed and/or copyrighted by other
- *  sources; see the CREDITS file for full details.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * Copyright (c) 2003, Robert Collins <robertc@squid-cache.org>
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
+/* DEBUG: section 86    ESI processing */
+
 #include "squid.h"
 #include "Debug.h"
 #include "fatal.h"
@@ -40,28 +17,29 @@
  */
 #if (USE_SQUID_ESI == 1)
 
-#include "esi/Sequence.h"
-#include "esi/Literal.h"
 #include "esi/Attempt.h"
 #include "esi/Except.h"
+#include "esi/Literal.h"
+#include "esi/Sequence.h"
 
 class esiExcept;
 
 esiSequence::~esiSequence ()
 {
     debugs(86, 5, "esiSequence::~esiSequence " << this);
+    FinishAllElements(elements); // finish if not already done
 }
 
 esiSequence::esiSequence(esiTreeParentPtr aParent, bool incrementalFlag) :
-        elements(),
-        processedcount(0),
-        parent(aParent),
-        mayFail_(true),
-        failed(false),
-        provideIncrementalData(incrementalFlag),
-        processing(false),
-        processingResult(ESI_PROCESS_COMPLETE),
-        nextElementToProcess_(0)
+    elements(),
+    processedcount(0),
+    parent(aParent),
+    mayFail_(true),
+    failed(false),
+    provideIncrementalData(incrementalFlag),
+    processing(false),
+    processingResult(ESI_PROCESS_COMPLETE),
+    nextElementToProcess_(0)
 {
     memset(&flags, 0, sizeof(flags));
 }
@@ -111,12 +89,13 @@ esiSequence::render(ESISegment::Pointer output)
 
     for (size_t i = 0; i < processedcount; ++i) {
         elements[i]->render(output);
-        elements.setNULL(i,i+1);
+        FinishAnElement(elements[i], i);
         /* FIXME: pass a ESISegment ** ? */
         output = output->tail();
     }
 
-    elements.pop_front (processedcount);
+    // prune completed elements
+    elements.erase(elements.begin(), elements.begin() + processedcount);
     processedcount = 0;
     assert (output->next == NULL);
 }
@@ -125,7 +104,7 @@ void
 esiSequence::finish()
 {
     debugs(86, 5, "esiSequence::finish: " << this << " is finished");
-    elements.setNULL(0, elements.size());
+    FinishAllElements(elements);
     parent = NULL;
 }
 
@@ -149,7 +128,7 @@ esiSequence::provideData (ESISegment::Pointer data, ESIElement *source)
     assert (index >= 0);
 
     /* remove the current node */
-    elements.setNULL(index, index+1);
+    FinishAnElement(elements[index], index);
 
     /* create a literal */
     esiLiteral *temp = new esiLiteral (data);
@@ -290,7 +269,7 @@ esiSequence::process (int inheritedVarsFlag)
             return processingResult;
 
         if (processingResult == ESI_PROCESS_FAILED) {
-            elements.setNULL (0, elements.size());
+            FinishAllElements(elements);
             failed = true;
             parent = NULL;
             processing = false;
@@ -336,19 +315,19 @@ esiSequence::fail (ESIElement *source, char const *anError)
 
     debugs(86, 5, "esiSequence::fail: " << this << " has failed.");
     parent->fail (this, anError);
-    elements.setNULL(0, elements.size());
+    FinishAllElements(elements);
     parent = NULL;
 }
 
 esiSequence::esiSequence(esiSequence const &old) :
-        processedcount(0),
-        parent(NULL),
-        mayFail_(old.mayFail_),
-        failed(old.failed),
-        provideIncrementalData(old.provideIncrementalData),
-        processing(false),
-        processingResult(ESI_PROCESS_COMPLETE),
-        nextElementToProcess_(0)
+    processedcount(0),
+    parent(NULL),
+    mayFail_(old.mayFail_),
+    failed(old.failed),
+    provideIncrementalData(old.provideIncrementalData),
+    processing(false),
+    processingResult(ESI_PROCESS_COMPLETE),
+    nextElementToProcess_(0)
 {
     flags.dovars = old.flags.dovars;
 }
@@ -414,3 +393,4 @@ esiSequence::makeUsable(esiTreeParentPtr newParent, ESIVarState &newVarState) co
 }
 
 #endif /* USE_SQUID_ESI == 1 */
+
