@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2016 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2018 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -119,7 +119,6 @@ class MemPools
 public:
     static MemPools &GetInstance();
     MemPools();
-    void init();
     void flushMeters();
 
     /**
@@ -170,8 +169,6 @@ public:
     ssize_t mem_idle_limit;
     int poolCount;
     bool defaultIsChunked;
-private:
-    static MemPools *Instance;
 };
 
 /**
@@ -324,13 +321,14 @@ struct _MemPoolGlobalStats {
 };
 
 /// \ingroup MemPoolsAPI
+/// Creates a named MemPool of elements with the given size
 #define memPoolCreate MemPools::GetInstance().create
 
 /* Allocator API */
 /**
  \ingroup MemPoolsAPI
  * Initialise iteration through all of the pools.
- \retval  Iterator for use by memPoolIterateNext() and memPoolIterateDone()
+ * \returns Iterator for use by memPoolIterateNext() and memPoolIterateDone()
  */
 extern MemPoolIterator * memPoolIterate(void);
 
@@ -350,16 +348,16 @@ extern void memPoolIterateDone(MemPoolIterator ** iter);
  \ingroup MemPoolsAPI
  \todo Stats API - not sured how to refactor yet
  *
- * Fills MemPoolGlobalStats with statistical data about overall
+ * Fills a MemPoolGlobalStats with statistical data about overall
  * usage for all pools.
  *
- \retval  Number of pools that have at least one object in use.
+ * \param stats   Object to be filled with statistical data.
+ *
+ * \return Number of pools that have at least one object in use.
  *        Ie. number of dirty pools.
  */
 extern int memPoolGetGlobalStats(MemPoolGlobalStats * stats);
 
-/// \ingroup MemPoolsAPI
-extern int memPoolInUseCount(MemAllocator *);
 /// \ingroup MemPoolsAPI
 extern int memPoolsTotalAllocated(void);
 
